﻿
DROP SEQUENCE SEC_AUTORIAS_OID;
DROP SEQUENCE SEC_AUTORES_OID;
DROP SEQUENCE SEC_LIBROS_OID;

DROP TABLE AUTORIAS;
DROP TABLE AUTORES;
DROP TABLE LIBROS;
	
CREATE TABLE AUTORES (
	NOMBRE VARCHAR2(25) NOT NULL,
	APELLIDOS VARCHAR2(75) NOT NULL,
	OID_AUTOR INTEGER NOT NULL,
	PRIMARY KEY (OID_AUTOR)	);

CREATE INDEX INDICE_AUTORES ON AUTORES(APELLIDOS,NOMBRE);	

CREATE TABLE LIBROS (
	TITULO VARCHAR2(100) NOT NULL,
	OID_LIBRO INTEGER NOT NULL,
	PRIMARY KEY (OID_LIBRO));
	
CREATE TABLE AUTORIAS (
	OID_LIBRO INTEGER NOT NULL,
	OID_AUTOR INTEGER NOT NULL,
	FOREIGN KEY (OID_LIBRO) REFERENCES LIBROS(OID_LIBRO),
	FOREIGN KEY (OID_AUTOR) REFERENCES AUTORES(OID_AUTOR), 
	OID_AUTORIA INTEGER NOT NULL,
	PRIMARY KEY (OID_AUTORIA) );

CREATE SEQUENCE SEC_AUTORIAS_OID
START WITH 1 INCREMENT BY 1 NOMAXVALUE;

CREATE SEQUENCE SEC_LIBROS_OID
START WITH 1 INCREMENT BY 1 NOMAXVALUE;

CREATE SEQUENCE SEC_AUTORES_OID
START WITH 1 INCREMENT BY 1 NOMAXVALUE;

CREATE OR REPLACE TRIGGER INSERTAR_AUTORIA_OID
BEFORE INSERT ON AUTORIAS
REFERENCING NEW AS NEW
FOR EACH ROW
BEGIN
  SELECT SEC_AUTORIAS_OID.NEXTVAL INTO :NEW.OID_AUTORIA FROM DUAL;
END;
/
CREATE OR REPLACE TRIGGER INSERTAR_LIBRO_OID
BEFORE INSERT ON LIBROS
REFERENCING NEW AS NEW
FOR EACH ROW
BEGIN
  SELECT SEC_LIBROS_OID.NEXTVAL INTO :NEW.OID_LIBRO FROM DUAL;
END;
/
CREATE OR REPLACE TRIGGER INSERTAR_AUTOR_OID
BEFORE INSERT ON AUTORES
REFERENCING NEW AS NEW
FOR EACH ROW
BEGIN
  SELECT SEC_AUTORES_OID.NEXTVAL INTO :NEW.OID_AUTOR FROM DUAL;
END;
/

CREATE OR REPLACE PROCEDURE INSERTAR_AUTOR 
  (P_NOM IN AUTORES.NOMBRE%TYPE,
   P_APE IN AUTORES.APELLIDOS%TYPE) IS
BEGIN
  INSERT INTO AUTORES(NOMBRE,APELLIDOS) 
  VALUES (P_NOM,P_APE);
END;
/
CREATE OR REPLACE PROCEDURE INSERTAR_LIBRO 
  (P_TIT IN LIBROS.TITULO%TYPE) IS
BEGIN
  INSERT INTO LIBROS(TITULO)
  VALUES (P_TIT);
END;
/
CREATE OR REPLACE PROCEDURE INSERTAR_AUTORIA 
  (FK_AUT IN AUTORIAS.OID_AUTOR%TYPE,
   FK_LIB IN LIBROS.OID_LIBRO%TYPE) IS
BEGIN
  INSERT INTO AUTORIAS(OID_AUTOR,OID_LIBRO)
  VALUES (FK_AUT,FK_LIB);
END;
/
CREATE OR REPLACE PROCEDURE QUITAR_LIBRO (OID_LIBRO_A_QUITAR IN LIBROS.OID_LIBRO%TYPE) IS
BEGIN
    DELETE FROM AUTORIAS WHERE OID_LIBRO = OID_LIBRO_A_QUITAR;
    DELETE FROM LIBROS WHERE OID_LIBRO = OID_LIBRO_A_QUITAR;
END;
/
CREATE OR REPLACE PROCEDURE MODIFICAR_TITULO 
(OID_LIBRO_A_MOD IN LIBROS.OID_LIBRO%TYPE,
 TIT_LIBRO_A_MOD IN LIBROS.TITULO%TYPE) IS
BEGIN
  UPDATE LIBROS SET TITULO=TIT_LIBRO_A_MOD
  WHERE OID_LIBRO = OID_LIBRO_A_MOD;
END;
/
